#' ---
#' title: |
#'   医薬品開発のための統計解析 第２部５章２節 \
#'   ２因子実験（質的因子×質的因子）\
#'   Green2-5-2.R
#' author: "Masahiko Katase"
#' date: "2021/7/2"
#' ---

#+ message = FALSE
library(readxl)    # read_excel
library(car)       # Anova
library(phia)      # interactionMeans
library(emmeans)   # emmeans
library(multcomp)  # cld

df <- read_excel("Green2-5.xlsx", sheet = "5-2inshi1")
df <- data.frame(df)
df <- df[, c(1,2,3)]  # "x"列は使わない

df$sex <- as.factor(df$sex)
df$group <- as.factor(df$group)

df1 <- subset(df, sex == "B1")
df2 <- subset(df, sex == "B2")

#'# 表示5.2.1 データと基本統計量（p.174）
s <- unstack(df1, df1$y ~  df1$group)  
s["mean",] <- colMeans(s)
s
s <- unstack(df2, df2$y ~  df2$group)  
s["mean",] <- colMeans(s)
s

interaction.plot(
  x.factor     = df$group,    # x軸
  trace.factor = df$sex,      # 区別する変数
  response     = df$y,        # y軸
  fun          = mean,        # 平均値をプロット
  type         = "b",         # 点と線のグラフ
  legend       = TRUE,        # 凡例を表示
  ylim         = c(10, 12),   # y軸の範囲
  xlab         = "Drug",      # x軸のタイトル
  ylab         = "response",  # y軸のタイトル
  trace.label  = "Sex",       # 凡例での区別するタイトル
  pch          = c(1, 2),     # 点の記号の種類
  cex.lab      = 1            # 軸タイトルの文字サイズ
)

#'# 表示5.2.2 雌雄別の分散分析表
lm_out1 <- lm(y ~ group, data = df1, 
              contrasts = list(group = "contr.sum"))
Anova(lm_out1, type = 3)

lm_out2 <- lm(y ~ group, data = df2, 
              contrasts = list(group = "contr.sum"))
Anova(lm_out2, type = 3)

#'# 表示5.2.3 雌雄合わせた分散分析表（p.176）、表示5.2.5・表示5.2.6 JMPによる解析結果
lm_out <- lm(y ~ sex + group + sex*group, data = df, 
             contrasts = list(sex = "contr.sum", 
                              group = "contr.sum"))
summary(lm_out)
Anova(lm_out, type = 3)

#'#　表示5.2.7 JMPの「プロファイル」出力
phia_out <- interactionMeans(lm_out)
phia_out
plot(phia_out)

#'# 表示5.2.8 欠測値のある場合の解
df3 <- df[-32, ]　# 32行目を削除
lm_out3 <- lm(y ~ sex + group + sex*group, data = df3, 
             contrasts = list(sex = "contr.sum", 
                              group = "contr.sum"))
summary(lm_out3)
Anova(lm_out3, type = 3)

#'# 個々の平均値の比較（補足、取り扱いに注意）
# ２要因のすべての組み合わせの対比較
emmeans_out <- emmeans(lm_out,
                       pairwise ~ sex:group,
                   　　adjust = "tukey")
emmeans_out$emmeans
emmeans_out$contrasts
confint(emmeans_out$contrasts)
summary(emmeans_out$contrasts, infer = TRUE)

# 雌雄別に薬剤を比較
emmeans(lm_out, specs = pairwise ~ group|sex, adjust = "tukey")

# 雌雄を合わせて主効果（薬剤）を比較
emmeans(lm_out, specs = pairwise ~ group, adjust = "tukey")

# ２要因のすべての組み合わせにおける対照との比較（Dunnettの方法）
emmeans(lm_out, specs = trt.vs.ctrl ~ sex:group)

