#' ---
#' title: |
#'   医薬品開発のための統計解析 第２部５章３節 \
#'   ２因子実験（質的因子×量的因子）\
#'   Green2-5-3.R
#' author: "Masahiko Katase"
#' date: "2021/7/16"
#' ---

#+ message = FALSE
library(readxl)    # read_excel
library(car)       # Anova

df <- read_excel("Green2-5.xlsx", sheet = "5-2inshi1")
df <- data.frame(df)
df <- df[, c(1, 3, 4)]  # "group"列は使わない
df$sex <- as.factor(df$sex)

#'# 表示5.3.1 解析用データ表と雌雄ごとの直線のあてはめ
df1 <- subset(df, sex == "B1", select = c(y, x))
df2 <- subset(df, sex == "B2", select = c(y, x))

lm_out1 <- lm(y ~ x, data = df1)
lm_out2 <- lm(y ~ x, data = df2)

g <- ifelse(df$sex == "B1", 1, 2)
plot(x = df$x, y = df$y, type = "p", col = g, pch = g, 
     xlim = c(0, 4), ylim = c(10, 12), ylab = "y", xlab = "x")
abline(lm_out1, col = 1)
abline(lm_out2, col = 2)

summary(lm_out1)
summary(lm_out2)

#'# 表示5.3.6 JMP による解析（主効果のみ）
lm_out3 <- lm(y ~ sex + x, data = df, 
              contrasts = list(sex = "contr.sum"))
summary(lm_out3)
Anova(lm_out3, type = 3)

# LOFの算出
lm_out_pe3 <- lm(y ~ sex * factor(x), data = df)
anova(lm_out3, lm_out_pe3)

# グラフ
b <- coef(lm_out3)
fn1 <- function(x) {b[1] + b[2] + b[3] * x}　　# B1の回帰式
fn2 <- function(x) {b[1] + (-b[2]) + b[3] * x} # B2の回帰式

plot(x = df$x, y = df$y, type = "p", col = g, pch = g, 
     xlim = c(0, 4), ylim = c(10, 12), ylab = "y", xlab = "x")
curve(fn1, xlim = c(0, 4), ylim = c(10, 12), col = 1, add = TRUE)
curve(fn2, xlim = c(0, 4), ylim = c(10, 12), col = 2, add = TRUE)

#'# 表示5.3.7 JMP による解析（交互作用を含む）
center <- mean(df$x)　　# 中心化
lm_out4 <- lm(y ~ sex * I(x - center), data = df, 
              contrasts = list(sex = "contr.sum"))
summary(lm_out4)
Anova(lm_out4, type = 3)

# LOF の算出
lm_out5 <- lm(y ~ sex * x, data = df)
lm_out_pe5 <- lm(y ~ sex * factor(x), data = df)
anova(lm_out5,lm_out_pe5)
