#' ---
#' title: |
#'   医薬品開発のための統計解析 第２部５章４節 \
#'   ２因子実験（質的因子×量的因子）変形\
#'   Green2-5-4.R
#' author: "Masahiko Katase"
#' date: "2021/7/16"
#' ---

#+ message = FALSE
library(readxl)    # read_excel
library(car)       # Anova

df <- read_excel("Green2-5.xlsx", sheet = "5-2inshi2")
df <- data.frame(df)
df$A <- as.factor(df$A)

#'# 表示5.4.2 平均値などの計算と散布図（p.191）
df1 <- cbind(df, r = 1:2)
xtabs(y ~ r + x + A, data = df1)

with(df, tapply(y, list(A, x), mean))

df1 <- subset(df, A == 1, select = c(y, x))
df2 <- subset(df, A == 2, select = c(y, x))

lm_out1 <- lm(y ~ x, data = df1)
lm_out2 <- lm(y ~ x, data = df2)

g <- unclass(df$A)
plot(x = df$x, y = df$y, type = "p", col = g, pch = g, 
     xlim = c(0, 3), ylim = c(10, 15), ylab = "y", xlab = "x")
abline(lm_out1, col = 1)
abline(lm_out2, col = 2)

summary(lm_out1)
summary(lm_out2)

#'# 表示5.4.5 JMP 出力（p.195）
lm_out3 <- lm(y ~ x + A:x, data = df, 
              contrasts = list(A = "contr.sum"))
summary(lm_out3)
Anova(lm_out3, type = 3)

# LOF
lm_out_pe <- lm(y ~ factor(x) + A:factor(x), data = df)
anova(lm_out3, lm_out_pe)

# グラフ
b <- coef(lm_out3)
fn1 <- function(x) {b[1] + b[2] * x + b[3] * x}
fn2 <- function(x) {b[1] + b[2] * x + (-b[3]) * x}
plot(x = df$x, y = df$y, type = "p", col = g, pch = g, 
     xlim = c(0, 3), ylim = c(10, 15), ylab = "y", xlab = "x")
curve(fn1, xlim = c(0, 3), ylim = c(10, 15), add = TRUE)
curve(fn2, xlim = c(0, 3), ylim = c(10, 15), add = TRUE)